# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import common_msgs_pb2 as common__msgs__pb2
import moby_msgs_pb2 as moby__msgs__pb2


class MobyStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetMobyState = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetMobyState',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.MobyState.FromString,
                )
        self.GetMobyErrorState = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetMobyErrorState',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.MobyErrorState.FromString,
                )
        self.Recover = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/Recover',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetMobyPose = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetMobyPose',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.MobyPose.FromString,
                )
        self.GetMobyVel = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetMobyVel',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.MobyVel.FromString,
                )
        self.ResetMobyPose = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/ResetMobyPose',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetRotationAngleDeg = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetRotationAngleDeg',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.SwerveDoubles.FromString,
                )
        self.GetDriveSpeed = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetDriveSpeed',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.SwerveDoubles.FromString,
                )
        self.GetTargetVel = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetTargetVel',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.TargetVel.FromString,
                )
        self.GetRotationZeroCount = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetRotationZeroCount',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.ZeroCount.FromString,
                )
        self.GetGyroData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetGyroData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.DoubleVals.FromString,
                )
        self.ResetGyroSensor = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/ResetGyroSensor',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.UseGyroForOdom = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/UseGyroForOdom',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetGyroFullData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetGyroFullData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.IMUData.FromString,
                )
        self.GetIRSensorData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetIRSensorData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.IRData.FromString,
                )
        self.GetUSSensorData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetUSSensorData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.USData.FromString,
                )
        self.GetBMSData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetBMSData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.BMSData.FromString,
                )
        self.SetStepControl = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetStepControl',
                request_serializer=moby__msgs__pb2.TargetVel.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.StopMotion = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/StopMotion',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetRotationAngleDeg = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetRotationAngleDeg',
                request_serializer=moby__msgs__pb2.SwerveDoubles.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.DriveWheel = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/DriveWheel',
                request_serializer=moby__msgs__pb2.SwerveDoubles.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetZeroPosAsCurrentPos = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetZeroPosAsCurrentPos',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetRotationVelAcc = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetRotationVelAcc',
                request_serializer=moby__msgs__pb2.DoubleVals.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetRotationInterpolator = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetRotationInterpolator',
                request_serializer=moby__msgs__pb2.IntVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetDriveAccDec = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetDriveAccDec',
                request_serializer=moby__msgs__pb2.DoubleVals.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetDriveInterpolatorOnOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetDriveInterpolatorOnOff',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetRotationControllerType = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetRotationControllerType',
                request_serializer=moby__msgs__pb2.IntVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetForceKinematics = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetForceKinematics',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetForceKinematics = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetForceKinematics',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.BoolVal.FromString,
                )
        self.PauseBumper = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/PauseBumper',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.TurnLightOnOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/TurnLightOnOff',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.TurnBuzzOnOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/TurnBuzzOnOff',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetControlParam = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetControlParam',
                request_serializer=moby__msgs__pb2.RotationGain.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetControlParam = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetControlParam',
                request_serializer=moby__msgs__pb2.IntVal.SerializeToString,
                response_deserializer=moby__msgs__pb2.RotationGain.FromString,
                )
        self.StartRTLogging = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/StartRTLogging',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.EndRTLogging = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/EndRTLogging',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )


class MobyServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetMobyState(self, request, context):
        """Get Moby state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMobyErrorState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Recover(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMobyPose(self, request, context):
        """Get Moby's odometry and physical data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMobyVel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetMobyPose(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRotationAngleDeg(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDriveSpeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTargetVel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRotationZeroCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGyroData(self, request, context):
        """Gyro value related
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetGyroSensor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UseGyroForOdom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGyroFullData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIRSensorData(self, request, context):
        """IR sensor
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUSSensorData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBMSData(self, request, context):
        """BMS data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetStepControl(self, request, context):
        """Moby motion command
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopMotion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRotationAngleDeg(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DriveWheel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetZeroPosAsCurrentPos(self, request, context):
        """Set Moby parameters
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRotationVelAcc(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRotationInterpolator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDriveAccDec(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDriveInterpolatorOnOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRotationControllerType(self, request, context):
        """rpc SetRotationInterpolatorParam(DoubleVals) returns (Empty) {}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetForceKinematics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetForceKinematics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseBumper(self, request, context):
        """Moby-Agri related commands
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TurnLightOnOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TurnBuzzOnOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetControlParam(self, request, context):
        """Gain setting
        rpc SetRotationTorqueMode(BoolVal) returns (Empty) {}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetControlParam(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartRTLogging(self, request, context):
        """Data logging
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EndRTLogging(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MobyServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetMobyState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMobyState,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.MobyState.SerializeToString,
            ),
            'GetMobyErrorState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMobyErrorState,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.MobyErrorState.SerializeToString,
            ),
            'Recover': grpc.unary_unary_rpc_method_handler(
                    servicer.Recover,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetMobyPose': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMobyPose,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.MobyPose.SerializeToString,
            ),
            'GetMobyVel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMobyVel,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.MobyVel.SerializeToString,
            ),
            'ResetMobyPose': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetMobyPose,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetRotationAngleDeg': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRotationAngleDeg,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.SwerveDoubles.SerializeToString,
            ),
            'GetDriveSpeed': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDriveSpeed,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.SwerveDoubles.SerializeToString,
            ),
            'GetTargetVel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTargetVel,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.TargetVel.SerializeToString,
            ),
            'GetRotationZeroCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRotationZeroCount,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.ZeroCount.SerializeToString,
            ),
            'GetGyroData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGyroData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.DoubleVals.SerializeToString,
            ),
            'ResetGyroSensor': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetGyroSensor,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'UseGyroForOdom': grpc.unary_unary_rpc_method_handler(
                    servicer.UseGyroForOdom,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetGyroFullData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGyroFullData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.IMUData.SerializeToString,
            ),
            'GetIRSensorData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIRSensorData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.IRData.SerializeToString,
            ),
            'GetUSSensorData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUSSensorData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.USData.SerializeToString,
            ),
            'GetBMSData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBMSData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.BMSData.SerializeToString,
            ),
            'SetStepControl': grpc.unary_unary_rpc_method_handler(
                    servicer.SetStepControl,
                    request_deserializer=moby__msgs__pb2.TargetVel.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'StopMotion': grpc.unary_unary_rpc_method_handler(
                    servicer.StopMotion,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetRotationAngleDeg': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRotationAngleDeg,
                    request_deserializer=moby__msgs__pb2.SwerveDoubles.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'DriveWheel': grpc.unary_unary_rpc_method_handler(
                    servicer.DriveWheel,
                    request_deserializer=moby__msgs__pb2.SwerveDoubles.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetZeroPosAsCurrentPos': grpc.unary_unary_rpc_method_handler(
                    servicer.SetZeroPosAsCurrentPos,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetRotationVelAcc': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRotationVelAcc,
                    request_deserializer=moby__msgs__pb2.DoubleVals.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetRotationInterpolator': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRotationInterpolator,
                    request_deserializer=moby__msgs__pb2.IntVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetDriveAccDec': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDriveAccDec,
                    request_deserializer=moby__msgs__pb2.DoubleVals.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetDriveInterpolatorOnOff': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDriveInterpolatorOnOff,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetRotationControllerType': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRotationControllerType,
                    request_deserializer=moby__msgs__pb2.IntVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetForceKinematics': grpc.unary_unary_rpc_method_handler(
                    servicer.SetForceKinematics,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetForceKinematics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetForceKinematics,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
            ),
            'PauseBumper': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseBumper,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'TurnLightOnOff': grpc.unary_unary_rpc_method_handler(
                    servicer.TurnLightOnOff,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'TurnBuzzOnOff': grpc.unary_unary_rpc_method_handler(
                    servicer.TurnBuzzOnOff,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetControlParam': grpc.unary_unary_rpc_method_handler(
                    servicer.SetControlParam,
                    request_deserializer=moby__msgs__pb2.RotationGain.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetControlParam': grpc.unary_unary_rpc_method_handler(
                    servicer.GetControlParam,
                    request_deserializer=moby__msgs__pb2.IntVal.FromString,
                    response_serializer=moby__msgs__pb2.RotationGain.SerializeToString,
            ),
            'StartRTLogging': grpc.unary_unary_rpc_method_handler(
                    servicer.StartRTLogging,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'EndRTLogging': grpc.unary_unary_rpc_method_handler(
                    servicer.EndRTLogging,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Nrmk.IndyFramework.Moby', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Moby(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetMobyState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetMobyState',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.MobyState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMobyErrorState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetMobyErrorState',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.MobyErrorState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Recover(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/Recover',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMobyPose(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetMobyPose',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.MobyPose.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMobyVel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetMobyVel',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.MobyVel.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetMobyPose(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/ResetMobyPose',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRotationAngleDeg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetRotationAngleDeg',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.SwerveDoubles.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDriveSpeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetDriveSpeed',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.SwerveDoubles.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTargetVel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetTargetVel',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.TargetVel.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRotationZeroCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetRotationZeroCount',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.ZeroCount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGyroData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetGyroData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.DoubleVals.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetGyroSensor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/ResetGyroSensor',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UseGyroForOdom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/UseGyroForOdom',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGyroFullData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetGyroFullData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.IMUData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIRSensorData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetIRSensorData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.IRData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUSSensorData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetUSSensorData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.USData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBMSData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetBMSData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.BMSData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetStepControl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetStepControl',
            moby__msgs__pb2.TargetVel.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopMotion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/StopMotion',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRotationAngleDeg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetRotationAngleDeg',
            moby__msgs__pb2.SwerveDoubles.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DriveWheel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/DriveWheel',
            moby__msgs__pb2.SwerveDoubles.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetZeroPosAsCurrentPos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetZeroPosAsCurrentPos',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRotationVelAcc(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetRotationVelAcc',
            moby__msgs__pb2.DoubleVals.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRotationInterpolator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetRotationInterpolator',
            moby__msgs__pb2.IntVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDriveAccDec(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetDriveAccDec',
            moby__msgs__pb2.DoubleVals.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDriveInterpolatorOnOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetDriveInterpolatorOnOff',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRotationControllerType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetRotationControllerType',
            moby__msgs__pb2.IntVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetForceKinematics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetForceKinematics',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetForceKinematics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetForceKinematics',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.BoolVal.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseBumper(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/PauseBumper',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TurnLightOnOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/TurnLightOnOff',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TurnBuzzOnOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/TurnBuzzOnOff',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetControlParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetControlParam',
            moby__msgs__pb2.RotationGain.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetControlParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetControlParam',
            moby__msgs__pb2.IntVal.SerializeToString,
            moby__msgs__pb2.RotationGain.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartRTLogging(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/StartRTLogging',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EndRTLogging(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/EndRTLogging',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
