# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ethercat_msgs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ethercat_msgs.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x65thercat_msgs.proto\x12\x12Nrmk.IndyFramework\"\x1e\n\x0cMasterStatus\x12\x0e\n\x06status\x18\x01 \x01(\r\"\x1d\n\x0bSlaveStatus\x12\x0e\n\x06status\x18\x01 \x03(\r\"\"\n\x10\x45\x63\x61tDomainStatus\x12\x0e\n\x06status\x18\x01 \x01(\r\" \n\x0f\x45\x63\x61tSystemReady\x12\r\n\x05ready\x18\x01 \x03(\x08\"\x1c\n\x0b\x45\x63\x61tServoOn\x12\r\n\x05servo\x18\x01 \x03(\x08\"\\\n\x0cSlaveTypeNum\x12\x11\n\tnum_servo\x18\x01 \x01(\r\x12\x13\n\x0bnum_ioboard\x18\x02 \x01(\r\x12\x13\n\x0bnum_endtool\x18\x03 \x01(\r\x12\x0f\n\x07num_dio\x18\x04 \x01(\r\" \n\nServoIndex\x12\x12\n\nservoIndex\x18\x01 \x01(\r\"\x1e\n\tEcatIndex\x12\x11\n\tecatIndex\x18\x01 \x01(\r\"w\n\x07ServoTx\x12\x12\n\nstatusWord\x18\x01 \x01(\r\x12\x12\n\nmodeOpDisp\x18\x02 \x01(\x05\x12\x16\n\x0e\x61\x63tualPosition\x18\x03 \x01(\x05\x12\x16\n\x0e\x61\x63tualVelocity\x18\x04 \x01(\x05\x12\x14\n\x0c\x61\x63tualTorque\x18\x05 \x01(\x05\"t\n\x07ServoRx\x12\x13\n\x0b\x63ontrolWord\x18\x01 \x01(\r\x12\x0e\n\x06modeOp\x18\x02 \x01(\x05\x12\x16\n\x0etargetPosition\x18\x03 \x01(\x03\x12\x16\n\x0etargetVelocity\x18\x04 \x01(\x05\x12\x14\n\x0ctargetTorque\x18\x05 \x01(\x05\"K\n\x0cServoTxIndex\x12\x12\n\nservoIndex\x18\x01 \x01(\r\x12\'\n\x02tx\x18\x02 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.ServoTx\"K\n\x0cServoRxIndex\x12\x12\n\nservoIndex\x18\x01 \x01(\r\x12\'\n\x02rx\x18\x02 \x01(\x0b\x32\x1b.Nrmk.IndyFramework.ServoRx\"\xdf\x01\n\x0bServoTxKeba\x12\x12\n\nstatusWord\x18\x01 \x01(\r\x12\x13\n\x0bstatusWord2\x18\x02 \x01(\r\x12\x13\n\x0bstatusWord3\x18\x03 \x01(\r\x12\x16\n\x0e\x61\x63tualPosition\x18\x04 \x01(\x05\x12\x17\n\x0f\x61\x63tualPosition2\x18\x05 \x01(\x05\x12\x17\n\x0f\x61\x63tualPosition3\x18\x06 \x01(\x05\x12\x16\n\x0e\x61\x63tualVelocity\x18\x07 \x01(\x05\x12\x17\n\x0f\x61\x63tualVelocity2\x18\x08 \x01(\x05\x12\x17\n\x0f\x61\x63tualVelocity3\x18\t \x01(\x05\"\xdc\x01\n\x0bServoRxKeba\x12\x13\n\x0b\x63ontrolWord\x18\x01 \x01(\r\x12\x14\n\x0c\x63ontrolWord2\x18\x02 \x01(\r\x12\x14\n\x0c\x63ontrolWord3\x18\x03 \x01(\r\x12\x16\n\x0etargetPosition\x18\x04 \x01(\x03\x12\x17\n\x0ftargetPosition2\x18\x05 \x01(\x03\x12\x17\n\x0ftargetPosition3\x18\x06 \x01(\x03\x12\x14\n\x0ctargetTorque\x18\x07 \x01(\x05\x12\x15\n\rtargetTorque2\x18\x08 \x01(\x05\x12\x15\n\rtargetTorque3\x18\t \x01(\x05\"S\n\x10ServoRxIndexKeba\x12\x12\n\nservoIndex\x18\x01 \x01(\r\x12+\n\x02rx\x18\x02 \x01(\x0b\x32\x1f.Nrmk.IndyFramework.ServoRxKeba\" \n\tServoTemp\x12\x13\n\x0btemperature\x18\x01 \x01(\x02\"\x1f\n\nServoError\x12\x11\n\terrorCode\x18\x01 \x01(\r\".\n\nServoBrake\x12\x11\n\tecatIndex\x18\x01 \x01(\r\x12\r\n\x05onoff\x18\x02 \x01(\x08\"R\n\x08\x46TSensor\x12\n\n\x02\x66x\x18\x01 \x01(\x05\x12\n\n\x02\x66y\x18\x02 \x01(\x05\x12\n\n\x02\x66z\x18\x03 \x01(\x05\x12\n\n\x02tx\x18\x04 \x01(\x05\x12\n\n\x02ty\x18\x05 \x01(\x05\x12\n\n\x02tz\x18\x06 \x01(\x05\"\x80\x01\n\tEndtoolTx\x12\x0e\n\x06status\x18\x01 \x01(\r\x12\x0e\n\x06\x62utton\x18\x02 \x01(\r\x12/\n\tft_sensor\x18\x03 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.FTSensor\x12\x10\n\x08\x66t_state\x18\x04 \x01(\r\x12\x10\n\x08\x66t_error\x18\x05 \x01(\r\"z\n\tEndtoolRx\x12\x0b\n\x03\x65qc\x18\x01 \x01(\r\x12\x0f\n\x07gripper\x18\x02 \x01(\r\x12\x10\n\x08\x66t_param\x18\x03 \x01(\r\x12\x10\n\x08led_mode\x18\x04 \x01(\r\x12\r\n\x05led_g\x18\x05 \x01(\r\x12\r\n\x05led_r\x18\x06 \x01(\r\x12\r\n\x05led_b\x18\x07 \x01(\r\"\x8c\x03\n\x10\x45ndtoolDockingTx\x12\x16\n\x0e\x64ocking_status\x18\x01 \x01(\r\x12\x16\n\x0e\x64ocking_button\x18\x02 \x01(\r\x12\x15\n\rdocking_dist1\x18\x03 \x01(\r\x12\x15\n\rdocking_dist2\x18\x04 \x01(\r\x12\x15\n\rdocking_dist3\x18\x05 \x01(\r\x12\x15\n\rdocking_dist4\x18\x06 \x01(\r\x12\x15\n\rdocking_dist5\x18\x07 \x01(\r\x12\x15\n\rdocking_dist6\x18\x08 \x01(\r\x12\x15\n\rdocking_dist7\x18\t \x01(\r\x12\x15\n\rdocking_dist8\x18\n \x01(\r\x12\x15\n\rdirect_status\x18\x0b \x01(\r\x12\x15\n\rdirect_button\x18\x0c \x01(\r\x12\x16\n\x0e\x64irect_encoder\x18\r \x01(\r\x12\x11\n\tjoystic1x\x18\x0e \x01(\r\x12\x11\n\tjoystic1y\x18\x0f \x01(\r\x12\x11\n\tjoystic2x\x18\x10 \x01(\r\x12\x11\n\tjoystic2y\x18\x11 \x01(\r\"\x84\x01\n\tIOBoardTx\x12\x0c\n\x04\x64i5v\x18\x01 \x01(\r\x12\x0e\n\x06\x64i24v1\x18\x02 \x01(\r\x12\x0e\n\x06\x64i24v2\x18\x03 \x01(\r\x12\x0b\n\x03\x61i1\x18\x04 \x01(\r\x12\x0b\n\x03\x61i2\x18\x05 \x01(\r\x12/\n\tft_sensor\x18\x06 \x01(\x0b\x32\x1c.Nrmk.IndyFramework.FTSensor\"e\n\tIOBoardRx\x12\x0c\n\x04\x64o5v\x18\x01 \x01(\r\x12\x0e\n\x06\x64o24v1\x18\x02 \x01(\r\x12\x0e\n\x06\x64o24v2\x18\x03 \x01(\r\x12\x0b\n\x03\x61o1\x18\x04 \x01(\r\x12\x0b\n\x03\x61o2\x18\x05 \x01(\r\x12\x10\n\x08\x66t_param\x18\x06 \x01(\r\"\x1c\n\x08\x44IOIndex\x12\x10\n\x08\x64ioIndex\x18\x01 \x01(\r\"4\n\x0f\x44IODigitalInput\x12\x10\n\x08\x64ioIndex\x18\x01 \x01(\r\x12\x0f\n\x07\x64i_list\x18\x02 \x03(\r\"5\n\x10\x44IODigitalOutput\x12\x10\n\x08\x64ioIndex\x18\x01 \x01(\r\x12\x0f\n\x07\x64o_list\x18\x02 \x03(\r\"+\n\nServoParam\x12\x10\n\x08slaveIdx\x18\x01 \x01(\r\x12\x0b\n\x03val\x18\x02 \x01(\x05\"\x18\n\tSDOIntVal\x12\x0b\n\x03val\x18\x01 \x01(\x05\"\x1a\n\x0bSDOFloatVal\x12\x0b\n\x03val\x18\x01 \x01(\x02\"\x18\n\tSDOStrVal\x12\x0b\n\x03val\x18\x01 \x01(\t\"\x0e\n\x0c\x45therCATInfo\"\x1f\n\x0eRobotZeroCount\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x62\x06proto3'
)




_MASTERSTATUS = _descriptor.Descriptor(
  name='MasterStatus',
  full_name='Nrmk.IndyFramework.MasterStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.MasterStatus.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=73,
)


_SLAVESTATUS = _descriptor.Descriptor(
  name='SlaveStatus',
  full_name='Nrmk.IndyFramework.SlaveStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.SlaveStatus.status', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=104,
)


_ECATDOMAINSTATUS = _descriptor.Descriptor(
  name='EcatDomainStatus',
  full_name='Nrmk.IndyFramework.EcatDomainStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.EcatDomainStatus.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=140,
)


_ECATSYSTEMREADY = _descriptor.Descriptor(
  name='EcatSystemReady',
  full_name='Nrmk.IndyFramework.EcatSystemReady',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ready', full_name='Nrmk.IndyFramework.EcatSystemReady.ready', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=174,
)


_ECATSERVOON = _descriptor.Descriptor(
  name='EcatServoOn',
  full_name='Nrmk.IndyFramework.EcatServoOn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servo', full_name='Nrmk.IndyFramework.EcatServoOn.servo', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=204,
)


_SLAVETYPENUM = _descriptor.Descriptor(
  name='SlaveTypeNum',
  full_name='Nrmk.IndyFramework.SlaveTypeNum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_servo', full_name='Nrmk.IndyFramework.SlaveTypeNum.num_servo', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_ioboard', full_name='Nrmk.IndyFramework.SlaveTypeNum.num_ioboard', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_endtool', full_name='Nrmk.IndyFramework.SlaveTypeNum.num_endtool', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_dio', full_name='Nrmk.IndyFramework.SlaveTypeNum.num_dio', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=298,
)


_SERVOINDEX = _descriptor.Descriptor(
  name='ServoIndex',
  full_name='Nrmk.IndyFramework.ServoIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servoIndex', full_name='Nrmk.IndyFramework.ServoIndex.servoIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=332,
)


_ECATINDEX = _descriptor.Descriptor(
  name='EcatIndex',
  full_name='Nrmk.IndyFramework.EcatIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ecatIndex', full_name='Nrmk.IndyFramework.EcatIndex.ecatIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=364,
)


_SERVOTX = _descriptor.Descriptor(
  name='ServoTx',
  full_name='Nrmk.IndyFramework.ServoTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statusWord', full_name='Nrmk.IndyFramework.ServoTx.statusWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modeOpDisp', full_name='Nrmk.IndyFramework.ServoTx.modeOpDisp', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPosition', full_name='Nrmk.IndyFramework.ServoTx.actualPosition', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualVelocity', full_name='Nrmk.IndyFramework.ServoTx.actualVelocity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualTorque', full_name='Nrmk.IndyFramework.ServoTx.actualTorque', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=485,
)


_SERVORX = _descriptor.Descriptor(
  name='ServoRx',
  full_name='Nrmk.IndyFramework.ServoRx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controlWord', full_name='Nrmk.IndyFramework.ServoRx.controlWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modeOp', full_name='Nrmk.IndyFramework.ServoRx.modeOp', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPosition', full_name='Nrmk.IndyFramework.ServoRx.targetPosition', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetVelocity', full_name='Nrmk.IndyFramework.ServoRx.targetVelocity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque', full_name='Nrmk.IndyFramework.ServoRx.targetTorque', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=487,
  serialized_end=603,
)


_SERVOTXINDEX = _descriptor.Descriptor(
  name='ServoTxIndex',
  full_name='Nrmk.IndyFramework.ServoTxIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servoIndex', full_name='Nrmk.IndyFramework.ServoTxIndex.servoIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx', full_name='Nrmk.IndyFramework.ServoTxIndex.tx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=680,
)


_SERVORXINDEX = _descriptor.Descriptor(
  name='ServoRxIndex',
  full_name='Nrmk.IndyFramework.ServoRxIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servoIndex', full_name='Nrmk.IndyFramework.ServoRxIndex.servoIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx', full_name='Nrmk.IndyFramework.ServoRxIndex.rx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=757,
)


_SERVOTXKEBA = _descriptor.Descriptor(
  name='ServoTxKeba',
  full_name='Nrmk.IndyFramework.ServoTxKeba',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statusWord', full_name='Nrmk.IndyFramework.ServoTxKeba.statusWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statusWord2', full_name='Nrmk.IndyFramework.ServoTxKeba.statusWord2', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statusWord3', full_name='Nrmk.IndyFramework.ServoTxKeba.statusWord3', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPosition', full_name='Nrmk.IndyFramework.ServoTxKeba.actualPosition', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPosition2', full_name='Nrmk.IndyFramework.ServoTxKeba.actualPosition2', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPosition3', full_name='Nrmk.IndyFramework.ServoTxKeba.actualPosition3', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualVelocity', full_name='Nrmk.IndyFramework.ServoTxKeba.actualVelocity', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualVelocity2', full_name='Nrmk.IndyFramework.ServoTxKeba.actualVelocity2', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualVelocity3', full_name='Nrmk.IndyFramework.ServoTxKeba.actualVelocity3', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=983,
)


_SERVORXKEBA = _descriptor.Descriptor(
  name='ServoRxKeba',
  full_name='Nrmk.IndyFramework.ServoRxKeba',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controlWord', full_name='Nrmk.IndyFramework.ServoRxKeba.controlWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controlWord2', full_name='Nrmk.IndyFramework.ServoRxKeba.controlWord2', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controlWord3', full_name='Nrmk.IndyFramework.ServoRxKeba.controlWord3', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPosition', full_name='Nrmk.IndyFramework.ServoRxKeba.targetPosition', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPosition2', full_name='Nrmk.IndyFramework.ServoRxKeba.targetPosition2', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPosition3', full_name='Nrmk.IndyFramework.ServoRxKeba.targetPosition3', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque', full_name='Nrmk.IndyFramework.ServoRxKeba.targetTorque', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque2', full_name='Nrmk.IndyFramework.ServoRxKeba.targetTorque2', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque3', full_name='Nrmk.IndyFramework.ServoRxKeba.targetTorque3', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=986,
  serialized_end=1206,
)


_SERVORXINDEXKEBA = _descriptor.Descriptor(
  name='ServoRxIndexKeba',
  full_name='Nrmk.IndyFramework.ServoRxIndexKeba',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servoIndex', full_name='Nrmk.IndyFramework.ServoRxIndexKeba.servoIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx', full_name='Nrmk.IndyFramework.ServoRxIndexKeba.rx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1291,
)


_SERVOTEMP = _descriptor.Descriptor(
  name='ServoTemp',
  full_name='Nrmk.IndyFramework.ServoTemp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='temperature', full_name='Nrmk.IndyFramework.ServoTemp.temperature', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1325,
)


_SERVOERROR = _descriptor.Descriptor(
  name='ServoError',
  full_name='Nrmk.IndyFramework.ServoError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errorCode', full_name='Nrmk.IndyFramework.ServoError.errorCode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1327,
  serialized_end=1358,
)


_SERVOBRAKE = _descriptor.Descriptor(
  name='ServoBrake',
  full_name='Nrmk.IndyFramework.ServoBrake',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ecatIndex', full_name='Nrmk.IndyFramework.ServoBrake.ecatIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onoff', full_name='Nrmk.IndyFramework.ServoBrake.onoff', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1360,
  serialized_end=1406,
)


_FTSENSOR = _descriptor.Descriptor(
  name='FTSensor',
  full_name='Nrmk.IndyFramework.FTSensor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fx', full_name='Nrmk.IndyFramework.FTSensor.fx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fy', full_name='Nrmk.IndyFramework.FTSensor.fy', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fz', full_name='Nrmk.IndyFramework.FTSensor.fz', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx', full_name='Nrmk.IndyFramework.FTSensor.tx', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ty', full_name='Nrmk.IndyFramework.FTSensor.ty', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tz', full_name='Nrmk.IndyFramework.FTSensor.tz', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1408,
  serialized_end=1490,
)


_ENDTOOLTX = _descriptor.Descriptor(
  name='EndtoolTx',
  full_name='Nrmk.IndyFramework.EndtoolTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.EndtoolTx.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='Nrmk.IndyFramework.EndtoolTx.button', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_sensor', full_name='Nrmk.IndyFramework.EndtoolTx.ft_sensor', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_state', full_name='Nrmk.IndyFramework.EndtoolTx.ft_state', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_error', full_name='Nrmk.IndyFramework.EndtoolTx.ft_error', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1493,
  serialized_end=1621,
)


_ENDTOOLRX = _descriptor.Descriptor(
  name='EndtoolRx',
  full_name='Nrmk.IndyFramework.EndtoolRx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eqc', full_name='Nrmk.IndyFramework.EndtoolRx.eqc', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gripper', full_name='Nrmk.IndyFramework.EndtoolRx.gripper', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_param', full_name='Nrmk.IndyFramework.EndtoolRx.ft_param', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led_mode', full_name='Nrmk.IndyFramework.EndtoolRx.led_mode', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led_g', full_name='Nrmk.IndyFramework.EndtoolRx.led_g', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led_r', full_name='Nrmk.IndyFramework.EndtoolRx.led_r', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='led_b', full_name='Nrmk.IndyFramework.EndtoolRx.led_b', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1623,
  serialized_end=1745,
)


_ENDTOOLDOCKINGTX = _descriptor.Descriptor(
  name='EndtoolDockingTx',
  full_name='Nrmk.IndyFramework.EndtoolDockingTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='docking_status', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_button', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_button', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist1', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist1', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist2', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist2', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist3', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist3', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist4', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist4', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist5', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist5', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist6', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist6', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist7', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist7', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='docking_dist8', full_name='Nrmk.IndyFramework.EndtoolDockingTx.docking_dist8', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_status', full_name='Nrmk.IndyFramework.EndtoolDockingTx.direct_status', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_button', full_name='Nrmk.IndyFramework.EndtoolDockingTx.direct_button', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_encoder', full_name='Nrmk.IndyFramework.EndtoolDockingTx.direct_encoder', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joystic1x', full_name='Nrmk.IndyFramework.EndtoolDockingTx.joystic1x', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joystic1y', full_name='Nrmk.IndyFramework.EndtoolDockingTx.joystic1y', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joystic2x', full_name='Nrmk.IndyFramework.EndtoolDockingTx.joystic2x', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joystic2y', full_name='Nrmk.IndyFramework.EndtoolDockingTx.joystic2y', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1748,
  serialized_end=2144,
)


_IOBOARDTX = _descriptor.Descriptor(
  name='IOBoardTx',
  full_name='Nrmk.IndyFramework.IOBoardTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='di5v', full_name='Nrmk.IndyFramework.IOBoardTx.di5v', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='di24v1', full_name='Nrmk.IndyFramework.IOBoardTx.di24v1', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='di24v2', full_name='Nrmk.IndyFramework.IOBoardTx.di24v2', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ai1', full_name='Nrmk.IndyFramework.IOBoardTx.ai1', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ai2', full_name='Nrmk.IndyFramework.IOBoardTx.ai2', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_sensor', full_name='Nrmk.IndyFramework.IOBoardTx.ft_sensor', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2147,
  serialized_end=2279,
)


_IOBOARDRX = _descriptor.Descriptor(
  name='IOBoardRx',
  full_name='Nrmk.IndyFramework.IOBoardRx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='do5v', full_name='Nrmk.IndyFramework.IOBoardRx.do5v', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do24v1', full_name='Nrmk.IndyFramework.IOBoardRx.do24v1', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do24v2', full_name='Nrmk.IndyFramework.IOBoardRx.do24v2', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ao1', full_name='Nrmk.IndyFramework.IOBoardRx.ao1', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ao2', full_name='Nrmk.IndyFramework.IOBoardRx.ao2', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ft_param', full_name='Nrmk.IndyFramework.IOBoardRx.ft_param', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2281,
  serialized_end=2382,
)


_DIOINDEX = _descriptor.Descriptor(
  name='DIOIndex',
  full_name='Nrmk.IndyFramework.DIOIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dioIndex', full_name='Nrmk.IndyFramework.DIOIndex.dioIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2384,
  serialized_end=2412,
)


_DIODIGITALINPUT = _descriptor.Descriptor(
  name='DIODigitalInput',
  full_name='Nrmk.IndyFramework.DIODigitalInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dioIndex', full_name='Nrmk.IndyFramework.DIODigitalInput.dioIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='di_list', full_name='Nrmk.IndyFramework.DIODigitalInput.di_list', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2414,
  serialized_end=2466,
)


_DIODIGITALOUTPUT = _descriptor.Descriptor(
  name='DIODigitalOutput',
  full_name='Nrmk.IndyFramework.DIODigitalOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dioIndex', full_name='Nrmk.IndyFramework.DIODigitalOutput.dioIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do_list', full_name='Nrmk.IndyFramework.DIODigitalOutput.do_list', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2468,
  serialized_end=2521,
)


_SERVOPARAM = _descriptor.Descriptor(
  name='ServoParam',
  full_name='Nrmk.IndyFramework.ServoParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='slaveIdx', full_name='Nrmk.IndyFramework.ServoParam.slaveIdx', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.ServoParam.val', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2523,
  serialized_end=2566,
)


_SDOINTVAL = _descriptor.Descriptor(
  name='SDOIntVal',
  full_name='Nrmk.IndyFramework.SDOIntVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.SDOIntVal.val', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2568,
  serialized_end=2592,
)


_SDOFLOATVAL = _descriptor.Descriptor(
  name='SDOFloatVal',
  full_name='Nrmk.IndyFramework.SDOFloatVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.SDOFloatVal.val', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2594,
  serialized_end=2620,
)


_SDOSTRVAL = _descriptor.Descriptor(
  name='SDOStrVal',
  full_name='Nrmk.IndyFramework.SDOStrVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.SDOStrVal.val', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2622,
  serialized_end=2646,
)


_ETHERCATINFO = _descriptor.Descriptor(
  name='EtherCATInfo',
  full_name='Nrmk.IndyFramework.EtherCATInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2648,
  serialized_end=2662,
)


_ROBOTZEROCOUNT = _descriptor.Descriptor(
  name='RobotZeroCount',
  full_name='Nrmk.IndyFramework.RobotZeroCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='Nrmk.IndyFramework.RobotZeroCount.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2664,
  serialized_end=2695,
)

_SERVOTXINDEX.fields_by_name['tx'].message_type = _SERVOTX
_SERVORXINDEX.fields_by_name['rx'].message_type = _SERVORX
_SERVORXINDEXKEBA.fields_by_name['rx'].message_type = _SERVORXKEBA
_ENDTOOLTX.fields_by_name['ft_sensor'].message_type = _FTSENSOR
_IOBOARDTX.fields_by_name['ft_sensor'].message_type = _FTSENSOR
DESCRIPTOR.message_types_by_name['MasterStatus'] = _MASTERSTATUS
DESCRIPTOR.message_types_by_name['SlaveStatus'] = _SLAVESTATUS
DESCRIPTOR.message_types_by_name['EcatDomainStatus'] = _ECATDOMAINSTATUS
DESCRIPTOR.message_types_by_name['EcatSystemReady'] = _ECATSYSTEMREADY
DESCRIPTOR.message_types_by_name['EcatServoOn'] = _ECATSERVOON
DESCRIPTOR.message_types_by_name['SlaveTypeNum'] = _SLAVETYPENUM
DESCRIPTOR.message_types_by_name['ServoIndex'] = _SERVOINDEX
DESCRIPTOR.message_types_by_name['EcatIndex'] = _ECATINDEX
DESCRIPTOR.message_types_by_name['ServoTx'] = _SERVOTX
DESCRIPTOR.message_types_by_name['ServoRx'] = _SERVORX
DESCRIPTOR.message_types_by_name['ServoTxIndex'] = _SERVOTXINDEX
DESCRIPTOR.message_types_by_name['ServoRxIndex'] = _SERVORXINDEX
DESCRIPTOR.message_types_by_name['ServoTxKeba'] = _SERVOTXKEBA
DESCRIPTOR.message_types_by_name['ServoRxKeba'] = _SERVORXKEBA
DESCRIPTOR.message_types_by_name['ServoRxIndexKeba'] = _SERVORXINDEXKEBA
DESCRIPTOR.message_types_by_name['ServoTemp'] = _SERVOTEMP
DESCRIPTOR.message_types_by_name['ServoError'] = _SERVOERROR
DESCRIPTOR.message_types_by_name['ServoBrake'] = _SERVOBRAKE
DESCRIPTOR.message_types_by_name['FTSensor'] = _FTSENSOR
DESCRIPTOR.message_types_by_name['EndtoolTx'] = _ENDTOOLTX
DESCRIPTOR.message_types_by_name['EndtoolRx'] = _ENDTOOLRX
DESCRIPTOR.message_types_by_name['EndtoolDockingTx'] = _ENDTOOLDOCKINGTX
DESCRIPTOR.message_types_by_name['IOBoardTx'] = _IOBOARDTX
DESCRIPTOR.message_types_by_name['IOBoardRx'] = _IOBOARDRX
DESCRIPTOR.message_types_by_name['DIOIndex'] = _DIOINDEX
DESCRIPTOR.message_types_by_name['DIODigitalInput'] = _DIODIGITALINPUT
DESCRIPTOR.message_types_by_name['DIODigitalOutput'] = _DIODIGITALOUTPUT
DESCRIPTOR.message_types_by_name['ServoParam'] = _SERVOPARAM
DESCRIPTOR.message_types_by_name['SDOIntVal'] = _SDOINTVAL
DESCRIPTOR.message_types_by_name['SDOFloatVal'] = _SDOFLOATVAL
DESCRIPTOR.message_types_by_name['SDOStrVal'] = _SDOSTRVAL
DESCRIPTOR.message_types_by_name['EtherCATInfo'] = _ETHERCATINFO
DESCRIPTOR.message_types_by_name['RobotZeroCount'] = _ROBOTZEROCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MasterStatus = _reflection.GeneratedProtocolMessageType('MasterStatus', (_message.Message,), {
  'DESCRIPTOR' : _MASTERSTATUS,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MasterStatus)
  })
_sym_db.RegisterMessage(MasterStatus)

SlaveStatus = _reflection.GeneratedProtocolMessageType('SlaveStatus', (_message.Message,), {
  'DESCRIPTOR' : _SLAVESTATUS,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SlaveStatus)
  })
_sym_db.RegisterMessage(SlaveStatus)

EcatDomainStatus = _reflection.GeneratedProtocolMessageType('EcatDomainStatus', (_message.Message,), {
  'DESCRIPTOR' : _ECATDOMAINSTATUS,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EcatDomainStatus)
  })
_sym_db.RegisterMessage(EcatDomainStatus)

EcatSystemReady = _reflection.GeneratedProtocolMessageType('EcatSystemReady', (_message.Message,), {
  'DESCRIPTOR' : _ECATSYSTEMREADY,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EcatSystemReady)
  })
_sym_db.RegisterMessage(EcatSystemReady)

EcatServoOn = _reflection.GeneratedProtocolMessageType('EcatServoOn', (_message.Message,), {
  'DESCRIPTOR' : _ECATSERVOON,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EcatServoOn)
  })
_sym_db.RegisterMessage(EcatServoOn)

SlaveTypeNum = _reflection.GeneratedProtocolMessageType('SlaveTypeNum', (_message.Message,), {
  'DESCRIPTOR' : _SLAVETYPENUM,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SlaveTypeNum)
  })
_sym_db.RegisterMessage(SlaveTypeNum)

ServoIndex = _reflection.GeneratedProtocolMessageType('ServoIndex', (_message.Message,), {
  'DESCRIPTOR' : _SERVOINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoIndex)
  })
_sym_db.RegisterMessage(ServoIndex)

EcatIndex = _reflection.GeneratedProtocolMessageType('EcatIndex', (_message.Message,), {
  'DESCRIPTOR' : _ECATINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EcatIndex)
  })
_sym_db.RegisterMessage(EcatIndex)

ServoTx = _reflection.GeneratedProtocolMessageType('ServoTx', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoTx)
  })
_sym_db.RegisterMessage(ServoTx)

ServoRx = _reflection.GeneratedProtocolMessageType('ServoRx', (_message.Message,), {
  'DESCRIPTOR' : _SERVORX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoRx)
  })
_sym_db.RegisterMessage(ServoRx)

ServoTxIndex = _reflection.GeneratedProtocolMessageType('ServoTxIndex', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTXINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoTxIndex)
  })
_sym_db.RegisterMessage(ServoTxIndex)

ServoRxIndex = _reflection.GeneratedProtocolMessageType('ServoRxIndex', (_message.Message,), {
  'DESCRIPTOR' : _SERVORXINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoRxIndex)
  })
_sym_db.RegisterMessage(ServoRxIndex)

ServoTxKeba = _reflection.GeneratedProtocolMessageType('ServoTxKeba', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTXKEBA,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoTxKeba)
  })
_sym_db.RegisterMessage(ServoTxKeba)

ServoRxKeba = _reflection.GeneratedProtocolMessageType('ServoRxKeba', (_message.Message,), {
  'DESCRIPTOR' : _SERVORXKEBA,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoRxKeba)
  })
_sym_db.RegisterMessage(ServoRxKeba)

ServoRxIndexKeba = _reflection.GeneratedProtocolMessageType('ServoRxIndexKeba', (_message.Message,), {
  'DESCRIPTOR' : _SERVORXINDEXKEBA,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoRxIndexKeba)
  })
_sym_db.RegisterMessage(ServoRxIndexKeba)

ServoTemp = _reflection.GeneratedProtocolMessageType('ServoTemp', (_message.Message,), {
  'DESCRIPTOR' : _SERVOTEMP,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoTemp)
  })
_sym_db.RegisterMessage(ServoTemp)

ServoError = _reflection.GeneratedProtocolMessageType('ServoError', (_message.Message,), {
  'DESCRIPTOR' : _SERVOERROR,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoError)
  })
_sym_db.RegisterMessage(ServoError)

ServoBrake = _reflection.GeneratedProtocolMessageType('ServoBrake', (_message.Message,), {
  'DESCRIPTOR' : _SERVOBRAKE,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoBrake)
  })
_sym_db.RegisterMessage(ServoBrake)

FTSensor = _reflection.GeneratedProtocolMessageType('FTSensor', (_message.Message,), {
  'DESCRIPTOR' : _FTSENSOR,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FTSensor)
  })
_sym_db.RegisterMessage(FTSensor)

EndtoolTx = _reflection.GeneratedProtocolMessageType('EndtoolTx', (_message.Message,), {
  'DESCRIPTOR' : _ENDTOOLTX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EndtoolTx)
  })
_sym_db.RegisterMessage(EndtoolTx)

EndtoolRx = _reflection.GeneratedProtocolMessageType('EndtoolRx', (_message.Message,), {
  'DESCRIPTOR' : _ENDTOOLRX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EndtoolRx)
  })
_sym_db.RegisterMessage(EndtoolRx)

EndtoolDockingTx = _reflection.GeneratedProtocolMessageType('EndtoolDockingTx', (_message.Message,), {
  'DESCRIPTOR' : _ENDTOOLDOCKINGTX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EndtoolDockingTx)
  })
_sym_db.RegisterMessage(EndtoolDockingTx)

IOBoardTx = _reflection.GeneratedProtocolMessageType('IOBoardTx', (_message.Message,), {
  'DESCRIPTOR' : _IOBOARDTX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IOBoardTx)
  })
_sym_db.RegisterMessage(IOBoardTx)

IOBoardRx = _reflection.GeneratedProtocolMessageType('IOBoardRx', (_message.Message,), {
  'DESCRIPTOR' : _IOBOARDRX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IOBoardRx)
  })
_sym_db.RegisterMessage(IOBoardRx)

DIOIndex = _reflection.GeneratedProtocolMessageType('DIOIndex', (_message.Message,), {
  'DESCRIPTOR' : _DIOINDEX,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DIOIndex)
  })
_sym_db.RegisterMessage(DIOIndex)

DIODigitalInput = _reflection.GeneratedProtocolMessageType('DIODigitalInput', (_message.Message,), {
  'DESCRIPTOR' : _DIODIGITALINPUT,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DIODigitalInput)
  })
_sym_db.RegisterMessage(DIODigitalInput)

DIODigitalOutput = _reflection.GeneratedProtocolMessageType('DIODigitalOutput', (_message.Message,), {
  'DESCRIPTOR' : _DIODIGITALOUTPUT,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DIODigitalOutput)
  })
_sym_db.RegisterMessage(DIODigitalOutput)

ServoParam = _reflection.GeneratedProtocolMessageType('ServoParam', (_message.Message,), {
  'DESCRIPTOR' : _SERVOPARAM,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ServoParam)
  })
_sym_db.RegisterMessage(ServoParam)

SDOIntVal = _reflection.GeneratedProtocolMessageType('SDOIntVal', (_message.Message,), {
  'DESCRIPTOR' : _SDOINTVAL,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SDOIntVal)
  })
_sym_db.RegisterMessage(SDOIntVal)

SDOFloatVal = _reflection.GeneratedProtocolMessageType('SDOFloatVal', (_message.Message,), {
  'DESCRIPTOR' : _SDOFLOATVAL,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SDOFloatVal)
  })
_sym_db.RegisterMessage(SDOFloatVal)

SDOStrVal = _reflection.GeneratedProtocolMessageType('SDOStrVal', (_message.Message,), {
  'DESCRIPTOR' : _SDOSTRVAL,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SDOStrVal)
  })
_sym_db.RegisterMessage(SDOStrVal)

EtherCATInfo = _reflection.GeneratedProtocolMessageType('EtherCATInfo', (_message.Message,), {
  'DESCRIPTOR' : _ETHERCATINFO,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.EtherCATInfo)
  })
_sym_db.RegisterMessage(EtherCATInfo)

RobotZeroCount = _reflection.GeneratedProtocolMessageType('RobotZeroCount', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTZEROCOUNT,
  '__module__' : 'ethercat_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.RobotZeroCount)
  })
_sym_db.RegisterMessage(RobotZeroCount)


# @@protoc_insertion_point(module_scope)
