# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: device.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import device_msgs_pb2 as device__msgs__pb2
import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='device.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0c\x64\x65vice.proto\x12\x12Nrmk.IndyFramework\x1a\x11\x64\x65vice_msgs.proto\x1a\x11\x63ommon_msgs.proto2\xd2\x0f\n\x06\x44\x65vice\x12J\n\tSetBrakes\x12\x1d.Nrmk.IndyFramework.MotorList\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12H\n\x0bSetServoAll\x12\x19.Nrmk.IndyFramework.State\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12\x45\n\x08SetServo\x12\x19.Nrmk.IndyFramework.Servo\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12H\n\x05SetDI\x12\x1f.Nrmk.IndyFramework.DigitalList\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12H\n\x05SetDO\x12\x1f.Nrmk.IndyFramework.DigitalList\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12Q\n\x08SetEndDI\x12%.Nrmk.IndyFramework.EndtoolSignalList\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12Q\n\x08SetEndDO\x12%.Nrmk.IndyFramework.EndtoolSignalList\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12G\n\x05SetAI\x12\x1e.Nrmk.IndyFramework.AnalogList\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12G\n\x05SetAO\x12\x1e.Nrmk.IndyFramework.AnalogList\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12J\n\x08SetEndAI\x12\x1e.Nrmk.IndyFramework.AnalogList\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12J\n\x08SetEndAO\x12\x1e.Nrmk.IndyFramework.AnalogList\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12\x45\n\x05GetDI\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.DigitalList\"\x00\x12\x45\n\x05GetDO\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.DigitalList\"\x00\x12N\n\x08GetEndDI\x12\x19.Nrmk.IndyFramework.Empty\x1a%.Nrmk.IndyFramework.EndtoolSignalList\"\x00\x12N\n\x08GetEndDO\x12\x19.Nrmk.IndyFramework.Empty\x1a%.Nrmk.IndyFramework.EndtoolSignalList\"\x00\x12\x44\n\x05GetAI\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1e.Nrmk.IndyFramework.AnalogList\"\x00\x12\x44\n\x05GetAO\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1e.Nrmk.IndyFramework.AnalogList\"\x00\x12G\n\x08GetEndAI\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1e.Nrmk.IndyFramework.AnalogList\"\x00\x12G\n\x08GetEndAO\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1e.Nrmk.IndyFramework.AnalogList\"\x00\x12K\n\tGetEL5001\x12\x19.Nrmk.IndyFramework.Empty\x1a!.Nrmk.IndyFramework.GetEL5001Data\"\x00\x12K\n\tGetEL5101\x12\x19.Nrmk.IndyFramework.Empty\x1a!.Nrmk.IndyFramework.GetEL5101Data\"\x00\x12L\n\rGetDeviceInfo\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1e.Nrmk.IndyFramework.DeviceInfo\"\x00\x12Z\n\x14GetBrakeControlStyle\x12\x19.Nrmk.IndyFramework.Empty\x1a%.Nrmk.IndyFramework.BrakeControlStyle\"\x00\x12S\n\x0fSetFTSensorType\x12 .Nrmk.IndyFramework.FTSensorType\x1a\x1c.Nrmk.IndyFramework.Response\"\x00\x12P\n\x0fGetFTSensorType\x12\x19.Nrmk.IndyFramework.Empty\x1a .Nrmk.IndyFramework.FTSensorType\"\x00\x12P\n\x0fGetFTSensorData\x12\x19.Nrmk.IndyFramework.Empty\x1a .Nrmk.IndyFramework.FTSensorData\"\x00\x62\x06proto3'
  ,
  dependencies=[device__msgs__pb2.DESCRIPTOR,common__msgs__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_DEVICE = _descriptor.ServiceDescriptor(
  name='Device',
  full_name='Nrmk.IndyFramework.Device',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=75,
  serialized_end=2077,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetBrakes',
    full_name='Nrmk.IndyFramework.Device.SetBrakes',
    index=0,
    containing_service=None,
    input_type=device__msgs__pb2._MOTORLIST,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServoAll',
    full_name='Nrmk.IndyFramework.Device.SetServoAll',
    index=1,
    containing_service=None,
    input_type=common__msgs__pb2._STATE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetServo',
    full_name='Nrmk.IndyFramework.Device.SetServo',
    index=2,
    containing_service=None,
    input_type=device__msgs__pb2._SERVO,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDI',
    full_name='Nrmk.IndyFramework.Device.SetDI',
    index=3,
    containing_service=None,
    input_type=device__msgs__pb2._DIGITALLIST,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDO',
    full_name='Nrmk.IndyFramework.Device.SetDO',
    index=4,
    containing_service=None,
    input_type=device__msgs__pb2._DIGITALLIST,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetEndDI',
    full_name='Nrmk.IndyFramework.Device.SetEndDI',
    index=5,
    containing_service=None,
    input_type=device__msgs__pb2._ENDTOOLSIGNALLIST,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetEndDO',
    full_name='Nrmk.IndyFramework.Device.SetEndDO',
    index=6,
    containing_service=None,
    input_type=device__msgs__pb2._ENDTOOLSIGNALLIST,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAI',
    full_name='Nrmk.IndyFramework.Device.SetAI',
    index=7,
    containing_service=None,
    input_type=device__msgs__pb2._ANALOGLIST,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAO',
    full_name='Nrmk.IndyFramework.Device.SetAO',
    index=8,
    containing_service=None,
    input_type=device__msgs__pb2._ANALOGLIST,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetEndAI',
    full_name='Nrmk.IndyFramework.Device.SetEndAI',
    index=9,
    containing_service=None,
    input_type=device__msgs__pb2._ANALOGLIST,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetEndAO',
    full_name='Nrmk.IndyFramework.Device.SetEndAO',
    index=10,
    containing_service=None,
    input_type=device__msgs__pb2._ANALOGLIST,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDI',
    full_name='Nrmk.IndyFramework.Device.GetDI',
    index=11,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._DIGITALLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDO',
    full_name='Nrmk.IndyFramework.Device.GetDO',
    index=12,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._DIGITALLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndDI',
    full_name='Nrmk.IndyFramework.Device.GetEndDI',
    index=13,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._ENDTOOLSIGNALLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndDO',
    full_name='Nrmk.IndyFramework.Device.GetEndDO',
    index=14,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._ENDTOOLSIGNALLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAI',
    full_name='Nrmk.IndyFramework.Device.GetAI',
    index=15,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._ANALOGLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAO',
    full_name='Nrmk.IndyFramework.Device.GetAO',
    index=16,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._ANALOGLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndAI',
    full_name='Nrmk.IndyFramework.Device.GetEndAI',
    index=17,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._ANALOGLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEndAO',
    full_name='Nrmk.IndyFramework.Device.GetEndAO',
    index=18,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._ANALOGLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEL5001',
    full_name='Nrmk.IndyFramework.Device.GetEL5001',
    index=19,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._GETEL5001DATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEL5101',
    full_name='Nrmk.IndyFramework.Device.GetEL5101',
    index=20,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._GETEL5101DATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDeviceInfo',
    full_name='Nrmk.IndyFramework.Device.GetDeviceInfo',
    index=21,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._DEVICEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBrakeControlStyle',
    full_name='Nrmk.IndyFramework.Device.GetBrakeControlStyle',
    index=22,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._BRAKECONTROLSTYLE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetFTSensorType',
    full_name='Nrmk.IndyFramework.Device.SetFTSensorType',
    index=23,
    containing_service=None,
    input_type=device__msgs__pb2._FTSENSORTYPE,
    output_type=common__msgs__pb2._RESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFTSensorType',
    full_name='Nrmk.IndyFramework.Device.GetFTSensorType',
    index=24,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._FTSENSORTYPE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFTSensorData',
    full_name='Nrmk.IndyFramework.Device.GetFTSensorData',
    index=25,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=device__msgs__pb2._FTSENSORDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DEVICE)

DESCRIPTOR.services_by_name['Device'] = _DEVICE

# @@protoc_insertion_point(module_scope)
