# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: moby.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import moby_msgs_pb2 as moby__msgs__pb2
import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='moby.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nmoby.proto\x12\x12Nrmk.IndyFramework\x1a\x0fmoby_msgs.proto\x1a\x11\x63ommon_msgs.proto2\x82\x16\n\x04Moby\x12J\n\x0cGetMobyState\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.MobyState\"\x00\x12T\n\x11GetMobyErrorState\x12\x19.Nrmk.IndyFramework.Empty\x1a\".Nrmk.IndyFramework.MobyErrorState\"\x00\x12\x41\n\x07Recover\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12H\n\x0bGetMobyPose\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1c.Nrmk.IndyFramework.MobyPose\"\x00\x12\x46\n\nGetMobyVel\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1b.Nrmk.IndyFramework.MobyVel\"\x00\x12G\n\rResetMobyPose\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12U\n\x13GetRotationAngleDeg\x12\x19.Nrmk.IndyFramework.Empty\x1a!.Nrmk.IndyFramework.SwerveDoubles\"\x00\x12O\n\rGetDriveSpeed\x12\x19.Nrmk.IndyFramework.Empty\x1a!.Nrmk.IndyFramework.SwerveDoubles\"\x00\x12J\n\x0cGetTargetVel\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.TargetVel\"\x00\x12R\n\x14GetRotationZeroCount\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.ZeroCount\"\x00\x12J\n\x0bGetGyroData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1e.Nrmk.IndyFramework.DoubleVals\"\x00\x12I\n\x0fResetGyroSensor\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0eUseGyroForOdom\x12\x1b.Nrmk.IndyFramework.BoolVal\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12K\n\x0fGetGyroFullData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1b.Nrmk.IndyFramework.IMUData\"\x00\x12J\n\x0fGetIRSensorData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1a.Nrmk.IndyFramework.IRData\"\x00\x12J\n\x0fGetUSSensorData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1a.Nrmk.IndyFramework.USData\"\x00\x12\x46\n\nGetBMSData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1b.Nrmk.IndyFramework.BMSData\"\x00\x12L\n\x0eSetStepControl\x12\x1d.Nrmk.IndyFramework.TargetVel\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12\x44\n\nStopMotion\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12U\n\x13SetRotationAngleDeg\x12!.Nrmk.IndyFramework.SwerveDoubles\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12L\n\nDriveWheel\x12!.Nrmk.IndyFramework.SwerveDoubles\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12P\n\x16SetZeroPosAsCurrentPos\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12P\n\x11SetRotationVelAcc\x12\x1e.Nrmk.IndyFramework.DoubleVals\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12R\n\x17SetRotationInterpolator\x12\x1a.Nrmk.IndyFramework.IntVal\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12M\n\x0eSetDriveAccDec\x12\x1e.Nrmk.IndyFramework.DoubleVals\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12U\n\x19SetDriveInterpolatorOnOff\x12\x1b.Nrmk.IndyFramework.BoolVal\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12T\n\x19SetRotationControllerType\x12\x1a.Nrmk.IndyFramework.IntVal\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12N\n\x12SetForceKinematics\x12\x1b.Nrmk.IndyFramework.BoolVal\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12N\n\x12GetForceKinematics\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1b.Nrmk.IndyFramework.BoolVal\"\x00\x12G\n\x0bPauseBumper\x12\x1b.Nrmk.IndyFramework.BoolVal\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12J\n\x0eTurnLightOnOff\x12\x1b.Nrmk.IndyFramework.BoolVal\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12I\n\rTurnBuzzOnOff\x12\x1b.Nrmk.IndyFramework.BoolVal\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12P\n\x0fSetControlParam\x12 .Nrmk.IndyFramework.RotationGain\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12Q\n\x0fGetControlParam\x12\x1a.Nrmk.IndyFramework.IntVal\x1a .Nrmk.IndyFramework.RotationGain\"\x00\x12H\n\x0eStartRTLogging\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x12\x46\n\x0c\x45ndRTLogging\x12\x19.Nrmk.IndyFramework.Empty\x1a\x19.Nrmk.IndyFramework.Empty\"\x00\x62\x06proto3'
  ,
  dependencies=[moby__msgs__pb2.DESCRIPTOR,common__msgs__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_MOBY = _descriptor.ServiceDescriptor(
  name='Moby',
  full_name='Nrmk.IndyFramework.Moby',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=71,
  serialized_end=2889,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMobyState',
    full_name='Nrmk.IndyFramework.Moby.GetMobyState',
    index=0,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._MOBYSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMobyErrorState',
    full_name='Nrmk.IndyFramework.Moby.GetMobyErrorState',
    index=1,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._MOBYERRORSTATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Recover',
    full_name='Nrmk.IndyFramework.Moby.Recover',
    index=2,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMobyPose',
    full_name='Nrmk.IndyFramework.Moby.GetMobyPose',
    index=3,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._MOBYPOSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMobyVel',
    full_name='Nrmk.IndyFramework.Moby.GetMobyVel',
    index=4,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._MOBYVEL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetMobyPose',
    full_name='Nrmk.IndyFramework.Moby.ResetMobyPose',
    index=5,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRotationAngleDeg',
    full_name='Nrmk.IndyFramework.Moby.GetRotationAngleDeg',
    index=6,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._SWERVEDOUBLES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDriveSpeed',
    full_name='Nrmk.IndyFramework.Moby.GetDriveSpeed',
    index=7,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._SWERVEDOUBLES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTargetVel',
    full_name='Nrmk.IndyFramework.Moby.GetTargetVel',
    index=8,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._TARGETVEL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRotationZeroCount',
    full_name='Nrmk.IndyFramework.Moby.GetRotationZeroCount',
    index=9,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._ZEROCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGyroData',
    full_name='Nrmk.IndyFramework.Moby.GetGyroData',
    index=10,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._DOUBLEVALS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetGyroSensor',
    full_name='Nrmk.IndyFramework.Moby.ResetGyroSensor',
    index=11,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UseGyroForOdom',
    full_name='Nrmk.IndyFramework.Moby.UseGyroForOdom',
    index=12,
    containing_service=None,
    input_type=moby__msgs__pb2._BOOLVAL,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGyroFullData',
    full_name='Nrmk.IndyFramework.Moby.GetGyroFullData',
    index=13,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._IMUDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIRSensorData',
    full_name='Nrmk.IndyFramework.Moby.GetIRSensorData',
    index=14,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._IRDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUSSensorData',
    full_name='Nrmk.IndyFramework.Moby.GetUSSensorData',
    index=15,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._USDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBMSData',
    full_name='Nrmk.IndyFramework.Moby.GetBMSData',
    index=16,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._BMSDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetStepControl',
    full_name='Nrmk.IndyFramework.Moby.SetStepControl',
    index=17,
    containing_service=None,
    input_type=moby__msgs__pb2._TARGETVEL,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopMotion',
    full_name='Nrmk.IndyFramework.Moby.StopMotion',
    index=18,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRotationAngleDeg',
    full_name='Nrmk.IndyFramework.Moby.SetRotationAngleDeg',
    index=19,
    containing_service=None,
    input_type=moby__msgs__pb2._SWERVEDOUBLES,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DriveWheel',
    full_name='Nrmk.IndyFramework.Moby.DriveWheel',
    index=20,
    containing_service=None,
    input_type=moby__msgs__pb2._SWERVEDOUBLES,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetZeroPosAsCurrentPos',
    full_name='Nrmk.IndyFramework.Moby.SetZeroPosAsCurrentPos',
    index=21,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRotationVelAcc',
    full_name='Nrmk.IndyFramework.Moby.SetRotationVelAcc',
    index=22,
    containing_service=None,
    input_type=moby__msgs__pb2._DOUBLEVALS,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRotationInterpolator',
    full_name='Nrmk.IndyFramework.Moby.SetRotationInterpolator',
    index=23,
    containing_service=None,
    input_type=moby__msgs__pb2._INTVAL,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDriveAccDec',
    full_name='Nrmk.IndyFramework.Moby.SetDriveAccDec',
    index=24,
    containing_service=None,
    input_type=moby__msgs__pb2._DOUBLEVALS,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDriveInterpolatorOnOff',
    full_name='Nrmk.IndyFramework.Moby.SetDriveInterpolatorOnOff',
    index=25,
    containing_service=None,
    input_type=moby__msgs__pb2._BOOLVAL,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRotationControllerType',
    full_name='Nrmk.IndyFramework.Moby.SetRotationControllerType',
    index=26,
    containing_service=None,
    input_type=moby__msgs__pb2._INTVAL,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetForceKinematics',
    full_name='Nrmk.IndyFramework.Moby.SetForceKinematics',
    index=27,
    containing_service=None,
    input_type=moby__msgs__pb2._BOOLVAL,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetForceKinematics',
    full_name='Nrmk.IndyFramework.Moby.GetForceKinematics',
    index=28,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=moby__msgs__pb2._BOOLVAL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseBumper',
    full_name='Nrmk.IndyFramework.Moby.PauseBumper',
    index=29,
    containing_service=None,
    input_type=moby__msgs__pb2._BOOLVAL,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TurnLightOnOff',
    full_name='Nrmk.IndyFramework.Moby.TurnLightOnOff',
    index=30,
    containing_service=None,
    input_type=moby__msgs__pb2._BOOLVAL,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TurnBuzzOnOff',
    full_name='Nrmk.IndyFramework.Moby.TurnBuzzOnOff',
    index=31,
    containing_service=None,
    input_type=moby__msgs__pb2._BOOLVAL,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetControlParam',
    full_name='Nrmk.IndyFramework.Moby.SetControlParam',
    index=32,
    containing_service=None,
    input_type=moby__msgs__pb2._ROTATIONGAIN,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetControlParam',
    full_name='Nrmk.IndyFramework.Moby.GetControlParam',
    index=33,
    containing_service=None,
    input_type=moby__msgs__pb2._INTVAL,
    output_type=moby__msgs__pb2._ROTATIONGAIN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartRTLogging',
    full_name='Nrmk.IndyFramework.Moby.StartRTLogging',
    index=34,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EndRTLogging',
    full_name='Nrmk.IndyFramework.Moby.EndRTLogging',
    index=35,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=common__msgs__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MOBY)

DESCRIPTOR.services_by_name['Moby'] = _MOBY

# @@protoc_insertion_point(module_scope)
